=======
History
=======

0.0.28 (2021-XX-XX)
-------------------

- Re-license project to parity license.

0.0.27 (2021-02-25)
-------------------

- Migrate to Fedora 33
- Migrate CI to GitHub actions.
- Improve documentation and static code tests.

0.0.26 (2020-10-04)
-------------------

- Working management functionality (alpha version) for Demo container.

0.0.21 (2020-09-25)
-------------------

- Added draft functionality for demo http container management.
- Added draft command line functionality.

0.0.20 (2020-09-01)
-------------------

- Working Fedora tests through Travis CI

0.0.19 (2020-08-30)
-------------------

- CI, job stages and deploy stage.

0.0.6 (2020-08-30)
------------------

- Polishing code quality support tools.

0.0.5 (2020-08-28)
------------------

- First release on PyPI.
